Learn R Programming

mokken (version 2.7.2)

mokken-package: Mokken Scale Analysis in R

Description

Mokken scale analysis (Mokken, 1971; Sijtsma and Molenaar, 2002) is a scaling procedure for both dichotomous and polytomous items. It consists of an item selection algorithm to partition a set of items into Mokken scales and several methods to check the assumptions of two nonparametric item response theory models: the monotone homogeneity model and the double monotonicity model. The output of this R-package resembles the output of the stand-alone program MSP (Molenaar and Sijtsma, 2000).

Arguments

Details

ll{ Package: mokken Type: Package Version: 2.7 Date: 2011-10-10 License: GPL Version 2 or later } The package contains principal functions for Mokken scale analysis. The package contains the following data sets ll{ acl Scores on a personality checklist. cavalini Scores on an inventory on industrial malodor transreas Scores on a transitive reasoning test } A guide for Mokken scale analysis in R for people who do not know R (Van der Ark, 2010) is available as a vignette from http://cran.r-project.org/web/packages/mokken/vignettes/mokken.pdf. Thanks are due to Geert H. van Kollenburg, Renske E. Kuijpers, Rudy Ligtvoet, J. Hendrik Straat, and Daniel van der Palm for contributing R code; to Geert H. van Kollenburg, Rudy Ligtvoet, Patrick Mair, and J. Hendrik Straat for testing the software; to Wijbrandt van Schuur for comments on the vignette; to Stephen Cubbellotti, Michael Dewey, Jasmin Durstin, Wilco H. M. Emons, Jue Huang, Michael Kubovy, Ivo Molenaar, Jonathan Rose, Tobias Schlaffer, Klaas Sijtsma, Iris Smits, Jia Jia Syu, Roger Watson, and Na Yang for reporting comments or bugs; to Harrie C. M. Vorst and Pierre Cavalini for permission to use their data; to Robert J. Mokken for lending his last name. Version 0 was introduced in Van der Ark (2007). It included the functions ll{ coefH Scalability coefficients coefZ Test statistics for scalability coefficients check.monotonicity Investigate monotonicity assumptions check.restscore Investigate nonintersection assumption using Method Restscore check.pmatrix Investigate nonintersection assumption using Method Pmatrix search.normal Mokken's automated item selection algorithm } The following major modifications have been made. ll{ aisp More general automated item selection algorithm. Function search has become obsolete (Version 2.0) check.reliability Compute reliability coefficients (Version 2.0) check.iio Investigate invariant item orderings (Version 2.4) coefH Standard errors for scalability coefficients included (Version 2.6) } All updates until version 2.7 are described in Van der Ark (in press). The following modifications have been made in Version 2.7 in comparison to previous versions. ll{ check.errors Inclusion new function to compute weighted Guttman errors for each person. check.iio plot has been added. check.monotonicity Computation of number of active pairs for dichotomous items has been corrected. check.pmatrix Summary of the results has been corrected. check.restscore Code pertaining to IIO has been deleted. The procedure is now equivalent to MSP. coefH Option included to compare scalability coefficients across groups } The following modifications have been made in Version 2.7.1 in comparison to previous versions. ll{ mokken Some legal issues } The following modifications have been made in Version 2.7.2 in comparison to previous versions. ll{ check.iio Violations of IIO for dichotomous items are now tested using a z-test rather than a t-test. }

References

Mokken, R. J. (1971) A Theory and Procedure of Scale Analysis. Berlin, Germany: De Gruyter. Molenaar, I.W. and Sijtsma, K. (2000) User's Manual MSP5 for Windows [Software manual]. Groningen, The Netherlands: IEC ProGAMMA. Sijtsma, K, and Molenaar, I. W. (2002) Introduction to nonparametric item response theory. Thousand Oaks, CA: Sage. Van der Ark, L. A. (2007). Mokken scale analysis in R. Journal of Statistical Software. http://www.jstatsoft.org/v20/i11 Van der Ark, L. A. (2010). Getting started with Mokken scale analysis in R. Unpublished manuscript. http://cran.r-project.org/web/packages/mokken/vignettes/mokken.pdf Van der Ark, L. A. (in press). New developments in Mokken scale analysis in R. Journal of Statistical Software.

Examples

Run this code
# Personality test
data(acl)               

# Select the items of the scale Communality
Communality <- acl[,1:10]

# Compute scalability coefficients
coefH(Communality)

# Investigate the assumption of monotonicity
monotonicity.list <- check.monotonicity(Communality)
summary(monotonicity.list)
plot(monotonicity.list)

# Investigate the assumption of non-intersecting ISRFs using method restscore
restscore.list <- check.restscore(Communality)
summary(restscore.list)
plot(restscore.list)

# Investigate the assumption of non-intersecting ISRFs using method pmatrix
pmatrix.list <- check.pmatrix(Communality)
summary(pmatrix.list)
plot(pmatrix.list)

# Investigate the assumption of IIO using method MIIO
iio.list <- check.iio(Communality)
summary(iio.list)
plot(iio.list)

# Compute the reliability of the scale
check.reliability(Communality)

# Partition the the scale into mokken scales
aisp(Communality)

Run the code above in your browser using DataLab